def copyright():
    print('''Copyright (c) 2001-2024 Python Software Foundation.
All Rights Reserved.

Copyright (c) 2000 BeOpen.com.
All Rights Reserved.

Copyright (c) 1995-2001 Corporation for National Research Initiatives.
All Rights Reserved.

Copyright (c) 1991-1995 Stichting Mathematisch Centrum, Amsterdam.
All Rights Reserved.

Copyright (C) 2021-2025 The EAMCVD Team. MIT License''')



import requests

ver = 1.0

BASE_URL = "https://axiom-mc.org/eamcvd/wp-json/wp/v2/posts"

def getByName(name):
    params = {
        "search": name,
        "per_page": 5
    }
    response = requests.get(BASE_URL, params=params)

    if response.status_code == 200:
        posts = response.json()
        if posts:
            return [{
                'title': post['title']['rendered'],
                'content': post['content']['rendered']
            } for post in posts]
        return "No blogs found with that name."
    return f"Error: {response.status_code}"

def getByID(id):
    params = {
        "search": 'eai-' + id,
        "per_page": 5
    }
    response = requests.get(BASE_URL, params=params)

    if response.status_code == 200:
        posts = response.json()
        if posts:
            return [{
                'title': post['title']['rendered'],
                'content': post['content']['rendered']
            } for post in posts]
        return "No blogs found with that ID."
    return f"Error: {response.status_code}"
    return f"Error: {response.status_code}"


from setuptools import setup, find_packages

setup(
    name="eamcvd",
    version="1.4.1",
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    author="The EAMCVD Team",
    author_email="info@axiom-mc.org",
    description="A library to fetch EAMCVD(elefant ai mod comp. and vulnerabilities database) incompatibility reports",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://axiom-mc.org/eamcvd",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
